![](https://cdn.discordapp.com/attachments/1161632954636832969/1165445403362214039/Frame_4_2.png?ex=6546e09d&is=65346b9d&hm=b53f338d49fed0193f9d5adcfce7eddf397e23814799c29033405196de7ba732&)
<h1 align=center>🔮 ZxFade 💜</h1>
<p align=center>A Python package to make your programs easy to use and nice to look at</p>

# Installation
```
pip install zxfade
```
